@@ -21,21 +21,21 @@ extern "C"
 }
 #include <iostream>
 #include <fstream>
-#include "zypp/base/LogTools.h"
-#include "zypp/base/IOStream.h"
-#include "zypp/base/InputStream.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/IOStream.h>
+#include <zypp/base/InputStream.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
 
-#include "zypp/ZConfig.h"
-#include "zypp/ZYppFactory.h"
-#include "zypp/PathInfo.h"
-#include "zypp/parser/IniDict.h"
+#include <zypp/ZConfig.h>
+#include <zypp/ZYppFactory.h>
+#include <zypp/PathInfo.h>
+#include <zypp/parser/IniDict.h>
 
-#include "zypp/sat/Pool.h"
-#include "zypp/sat/detail/PoolImpl.h"
+#include <zypp/sat/Pool.h>
+#include <zypp/sat/detail/PoolImpl.h>
 
-using namespace std;
+using std::endl;
 using namespace zypp::filesystem;
 using namespace zypp::parser;
 
@@ -326,6 +326,7 @@ namespace zypp
 	, gpgCheck			( true )
 	, repoGpgCheck			( indeterminate )
 	, pkgGpgCheck			( indeterminate )
+	, solver_focus			( ResolverFocus::Default )
         , solver_onlyRequires		( false )
         , solver_allowVendorChange	( false )
 	, solver_dupAllowDowngrade	( true )
@@ -338,7 +339,7 @@ namespace zypp
         , apply_locks_file		( true )
         , pluginsPath			( "/usr/lib/zypp/plugins" )
       {
-        MIL << "libzypp: " << VERSION << endl;
+        MIL << "libzypp: " LIBZYPP_VERSION_STRING << endl;
         // override_r has higest prio
         // ZYPP_CONF might override /etc/zypp/zypp.conf
         if ( _parsedZyppConf.empty() )
@@ -359,14 +360,14 @@ namespace zypp
                 sit != dict.sectionsEnd();
                 ++sit )
           {
-            string section(*sit);
+            std::string section(*sit);
             //MIL << section << endl;
             for ( IniDict::entry_const_iterator it = dict.entriesBegin(*sit);
                   it != dict.entriesEnd(*sit);
                   ++it )
             {
-              string entry(it->first);
-              string value(it->second);
+              std::string entry(it->first);
+              std::string value(it->second);
               //DBG << (*it).first << "=" << (*it).second << endl;
               if ( section == "main" )
               {
@@ -494,6 +495,14 @@ namespace zypp
                 {
                   cfg_multiversion_path = Pathname(value);
                 }
+                else if ( entry == "multiversion.kernels" )
+                {
+                  cfg_kernel_keep_spec = value;
+                }
+                else if ( entry == "solver.focus" )
+                {
+		  fromString( value, solver_focus );
+                }
                 else if ( entry == "solver.onlyRequires" )
                 {
                   solver_onlyRequires.set( str::strToBool( value, solver_onlyRequires ) );
@@ -632,6 +641,7 @@ namespace zypp
 
     Pathname cfg_vendor_path;
     Pathname cfg_multiversion_path;
+    std::string cfg_kernel_keep_spec;
     Pathname locks_file;
 
     Pathname update_data_path;
@@ -661,6 +671,7 @@ namespace zypp
     DefaultOption<TriBool>	repoGpgCheck;
     DefaultOption<TriBool>	pkgGpgCheck;
 
+    ResolverFocus	solver_focus;
     Option<bool>	solver_onlyRequires;
     Option<bool>	solver_allowVendorChange;
     Option<bool>	solver_dupAllowDowngrade;
@@ -706,7 +717,7 @@ namespace zypp
 	// _specMap[root] - scan root/zypp.conf and root/multiversion.d
 
 	if ( root_r.empty() )
-	  root_r == "/";
+	  root_r = "/";
 	bool cacheHit = _specMap.count( root_r );
 	MultiversionSpec & ret( _specMap[root_r] );	// creates new entry on the fly
 
@@ -1067,6 +1078,7 @@ namespace zypp
   void ZConfig::resetRepoGpgCheck()			{ _pimpl->repoGpgCheck.restoreToDefault(); }
   void ZConfig::resetPkgGpgCheck()			{ _pimpl->pkgGpgCheck.restoreToDefault(); }
 
+  ResolverFocus ZConfig::solver_focus() const		{ return _pimpl->solver_focus; }
 
   bool ZConfig::solver_onlyRequires() const
   { return _pimpl->solver_onlyRequires; }
@@ -1175,11 +1187,16 @@ namespace zypp
   Pathname ZConfig::pluginsPath() const
   { return _pimpl->pluginsPath.get(); }
 
+  std::string ZConfig::multiversionKernels() const
+  {
+    return _pimpl->cfg_kernel_keep_spec;
+  }
+
   ///////////////////////////////////////////////////////////////////
 
   std::ostream & ZConfig::about( std::ostream & str ) const
   {
-    str << "libzypp: " << VERSION << endl;
+    str << "libzypp: " LIBZYPP_VERSION_STRING << endl;
 
     str << "libsolv: " << solv_version;
     if ( ::strcmp( solv_version, LIBSOLV_VERSION_STRING ) )
