@@ -9,16 +9,16 @@
 #include <iostream>
 #include <fstream>
 
-#include "zypp/base/LogTools.h"
-#include "zypp/base/String.h"
-#include "zypp/base/Regex.h"
+#include <zypp/base/LogTools.h>
+#include <zypp/base/String.h>
+#include <zypp/base/Regex.h>
 
-#include "zypp/ZYppFactory.h"
-#include "zypp/ZConfig.h"
-#include "zypp/Target.h"
-#include "zypp/Arch.h"
-#include "zypp/repo/RepoVariables.h"
-#include "zypp/base/NonCopyable.h"
+#include <zypp/ZYppFactory.h>
+#include <zypp/ZConfig.h>
+#include <zypp/Target.h>
+#include <zypp/Arch.h>
+#include <zypp/repo/RepoVariables.h>
+#include <zypp/base/NonCopyable.h>
 
 #define ZYPP_DBG_VAREXPAND 0
 #if ( ZYPP_DBG_VAREXPAND )
@@ -400,6 +400,11 @@ namespace zypp
       private:
 	const std::string * _lookup( const std::string & name_r )
 	{
+	  // Safe guard in case the caller does not own a zypp instance. In this case
+	  // getZYpp()->getTarget() in checkOverride would create a zypp instance which
+	  // would clear the variables parsed so far.
+	  auto guard { getZYpp() };
+
 	  if ( empty() )	// at init / after reset
 	  {
 	    // load user definitions from vars.d
